Documentation
¶
Overview ¶
Package ldapctl provides a simple ldap client to authenticate, retrieve basic information and groups for a user.
Index ¶
- func Command() *cobra.Command
- func LdapCheckCmd(cmd *cobra.Command, args []string) error
- type LDAPClient
- func (lc *LDAPClient) Authenticate(username, password string) (bool, map[string]string, error)
- func (lc *LDAPClient) Bind() error
- func (lc *LDAPClient) Close()
- func (lc *LDAPClient) Connect() error
- func (lc *LDAPClient) GetGroupsOfUser(username string) ([]string, error)
- func (lc LDAPClient) LogValue() slog.Value
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type LDAPClient ¶
type LDAPClient struct {
*ldap.Conn
Attributes []string
Base string
BindDN string
BindPassword string
GroupFilter string // e.g. "(memberUid=%s)"
Host string
ServerName string
UserFilter string // e.g. "(uid=%s)"
Port int
InsecureSkipVerify bool
UseSSL bool
SkipTLS bool
ClientCertificates []tls.Certificate // Adding client certificates
}
func (*LDAPClient) Authenticate ¶
Authenticate authenticates the user against the ldap backend.
func (*LDAPClient) Bind ¶
func (lc *LDAPClient) Bind() error
func (*LDAPClient) Connect ¶
func (lc *LDAPClient) Connect() error
Connect connects to the ldap backend.
func (*LDAPClient) GetGroupsOfUser ¶
func (lc *LDAPClient) GetGroupsOfUser(username string) ([]string, error)
GetGroupsOfUser returns the group for a user.
func (LDAPClient) LogValue ¶
func (lc LDAPClient) LogValue() slog.Value
Click to show internal directories.
Click to hide internal directories.